<?php

namespace DevOwl\RealCategoryLibrary\lite;

use DevOwl\RealCategoryLibrary\Vendor\DevOwl\Freemium\CorePro;
use DevOwl\RealCategoryLibrary\Vendor\MatthiasWeb\Utils\ExpireOption;
use MatthiasWeb\WPU\V4\WPLSController;
// @codeCoverageIgnoreStart
\defined('ABSPATH') or die('No script kiddies please!');
// Avoid direct file request
// @codeCoverageIgnoreEnd
trait Core {
    use CorePro;
    /**
     * The updater instance.
     *
     * @see https://github.com/Capevace/wordpress-plugin-updater
     */
    private $updater;
    // Documented in IOverrideCore
    public function overrideConstruct() {
        add_action('init', [new \DevOwl\RealCategoryLibrary\lite\PageCategory(), 'register_page_cat'], 99999);
        $this->getUpdater();
        // Initially load the updater
    }
    // Documented in IOverrideCore
    public function overrideInit() {
        // Show plugin notice
        if (!$this->getUpdater()->isActivated()) {
            add_action('after_plugin_row_' . plugin_basename(RCL_FILE), [$this, 'after_plugin_row'], 10, 2);
        }
    }
    /**
     * Show a notice in the plugins list that the plugin is not activated, yet.
     *
     * @param string $file
     * @param string $plugin
     */
    public function after_plugin_row($file, $plugin) {
        $wp_list_table = _get_list_table('WP_Plugins_List_Table');
        \printf(
            '<tr class="rcl-update-notice active">
	<th colspan="%d" class="check-column">
    	<div class="plugin-update update-message notice inline notice-warning notice-alt">
        	<div class="update-message">%s</div>
    	</div>
    </th>
</tr>',
            $wp_list_table->get_column_count(),
            wpautop(
                __(
                    '<strong>You have not yet entered the license key</strong>. To receive automatic updates, please enter the key in "Enter license".',
                    RCL_TD
                )
            )
        );
    }
    // Documented in IOverrideCore
    public function isLicenseNoticeDismissed($set = null) {
        $value = '1';
        $expireOption = new \DevOwl\RealCategoryLibrary\Vendor\MatthiasWeb\Utils\ExpireOption(
            RCL_OPT_PREFIX . '_licenseActivated',
            \false,
            365 * \constant('DAY_IN_SECONDS')
        );
        $expireOption->enableTransientMigration(
            \DevOwl\RealCategoryLibrary\Vendor\MatthiasWeb\Utils\ExpireOption::TRANSIENT_MIGRATION_SITE_WIDE
        );
        if ($set !== null) {
            $expireOption->set($set ? $value : 0);
        }
        return $expireOption->get() === $value;
    }
    /**
     * Send an email newsletter if checked in the updater.
     *
     * @param string $email
     */
    public function handleNewsletter($email) {
        wp_remote_post('https://devowl.io/wp-json/devowl-site/v1/plugin-activation-newsletter', [
            'body' => ['email' => $email, 'referer' => home_url(), 'slug' => RCL_SLUG]
        ]);
    }
    // Documented in IOverrideCore
    public function getUpdater() {
        if ($this->updater === null) {
            $this->updater = \MatthiasWeb\WPU\V4\WPLSController::initClient('https://license.matthias-web.com/', [
                'name' => 'WP Real Category Management',
                'version' => RCL_VERSION,
                'path' => RCL_FILE,
                'slug' => RCL_SLUG,
                'newsletterPrivacy' => 'https://devowl.io/privacy-policy/'
            ]);
            add_action('wpls_email_' . RCL_SLUG, [$this, 'handleNewsletter']);
        }
        return $this->updater;
    }
}
